pub struct Port {
pub broadcast_name: PortId,
pub impl_name: String,
pub display_name: String,
pub description: Option<String>,
pub required: bool,
}Expand description
Port configuration for a node
Fields
broadcast_name: PortIdBroadcast name (external name for connections between nodes)
impl_name: StringImplementation name (internal name used within the node function)
display_name: StringHuman-readable display name
description: Option<String>Port description
required: boolWhether this port is required
Implementations
Sourceimpl Port
impl Port
Sourcepub fn new(
broadcast_name: impl Into<String>,
impl_name: impl Into<String>,
) -> Self
pub fn new( broadcast_name: impl Into<String>, impl_name: impl Into<String>, ) -> Self
Create a new required port with separate broadcast and implementation names
Sourcepub fn simple(name: impl Into<String>) -> Self
pub fn simple(name: impl Into<String>) -> Self
Create a port where broadcast and implementation names are the same
Sourcepub fn optional(
broadcast_name: impl Into<String>,
impl_name: impl Into<String>,
) -> Self
pub fn optional( broadcast_name: impl Into<String>, impl_name: impl Into<String>, ) -> Self
Create a new optional port
Sourcepub fn with_display_name(self, display_name: impl Into<String>) -> Self
pub fn with_display_name(self, display_name: impl Into<String>) -> Self
Set the display name for this port
Sourcepub fn with_description(self, description: impl Into<String>) -> Self
pub fn with_description(self, description: impl Into<String>) -> Self
Set the description for this port